@@ -37,12 +37,32 @@ function benchStats(name, n, t1, t2) {
     `n = ${n}, dt = ${dt.toFixed(3)}s, r = ${r.toFixed(0)}/s, t = ${ns}ns/op`;
 }
 
+function benchB64RtLong() {
+  const input = "long-string".repeat(99999);
+  benchSync("b64_rt_long", 100, () => {
+    atob(btoa(input));
+  });
+}
+
+function benchB64RtShort() {
+  benchSync("b64_rt_short", 1e6, () => {
+    atob(btoa("123"));
+  });
+}
+
 function benchUrlParse() {
   benchSync("url_parse", 5e4, (i) => {
     new URL(`http://www.google.com/${i}`);
   });
 }
 
+function benchLargeBlobText() {
+  const input = "long-string".repeat(999_999);
+  benchSync("blob_text_large", 100, () => {
+    new Blob([input]).text();
+  });
+}
+
 function benchDateNow() {
   benchSync("date_now", 5e5, () => {
     Date.now();
@@ -110,6 +130,9 @@ async function main() {
   // A common "language feature", that should be fast
   // also a decent representation of a non-trivial JSON-op
   benchUrlParse();
+  benchLargeBlobText();
+  benchB64RtLong();
+  benchB64RtShort();
   // IO ops
   benchReadZero();
   benchWriteNull();
