@@ -762,7 +762,7 @@ impl Inner {
       let watch_registration_options =
         DidChangeWatchedFilesRegistrationOptions {
           watchers: vec![FileSystemWatcher {
-            glob_pattern: "**/*.json".to_string(),
+            glob_pattern: "**/*.json{c}".to_string(),
             kind: Some(WatchKind::Change),
           }],
         };
@@ -1063,11 +1063,12 @@ impl Inner {
       };
 
       match format_result {
-        Ok(new_text) => Some(text::get_edits(
+        Ok(Some(new_text)) => Some(text::get_edits(
           document.content().as_str(),
           &new_text,
           document.line_index().as_ref(),
         )),
+        Ok(None) => Some(Vec::new()),
         Err(err) => {
           // TODO(lucacasonato): handle error properly
           warn!("Format error: {}", err);
