@@ -6,7 +6,7 @@ use crate::proc_state::ProcState;
 use crate::source_maps::get_orig_position;
 use crate::source_maps::CachedMaps;
 use deno_core::error::AnyError;
-use deno_core::op_sync;
+use deno_core::op;
 use deno_core::serde_json;
 use deno_core::serde_json::json;
 use deno_core::serde_json::Value;
@@ -19,9 +19,9 @@ use std::collections::HashMap;
 pub fn init() -> Extension {
   Extension::builder()
     .ops(vec![
-      ("op_apply_source_map", op_sync(op_apply_source_map)),
-      ("op_format_diagnostic", op_sync(op_format_diagnostic)),
-      ("op_format_file_name", op_sync(op_format_file_name)),
+      op_apply_source_map::decl(),
+      op_format_diagnostic::decl(),
+      op_format_file_name::decl(),
     ])
     .build()
 }
@@ -42,10 +42,10 @@ struct AppliedSourceMap {
   column_number: u32,
 }
 
+#[op]
 fn op_apply_source_map(
   state: &mut OpState,
   args: ApplySourceMap,
-  _: (),
 ) -> Result<AppliedSourceMap, AnyError> {
   let mut mappings_map: CachedMaps = HashMap::new();
   let ps = state.borrow::<ProcState>().clone();
@@ -66,19 +66,13 @@ fn op_apply_source_map(
   })
 }
 
-fn op_format_diagnostic(
-  _state: &mut OpState,
-  args: Value,
-  _: (),
-) -> Result<Value, AnyError> {
+#[op]
+fn op_format_diagnostic(args: Value) -> Result<Value, AnyError> {
   let diagnostic: Diagnostics = serde_json::from_value(args)?;
   Ok(json!(diagnostic.to_string()))
 }
 
-fn op_format_file_name(
-  _state: &mut OpState,
-  file_name: String,
-  _: (),
-) -> Result<String, AnyError> {
+#[op]
+fn op_format_file_name(file_name: String) -> Result<String, AnyError> {
   Ok(format_file_name(&file_name))
 }
