@@ -27,3 +27,21 @@ export function pathToAbsoluteFileUrl(path: string): URL {
 
   return new URL(`file://${Deno.build.os === "windows" ? "/" : ""}${path}`);
 }
+
+const decoder = new TextDecoder();
+
+export async function execCode(code: string) {
+  const p = Deno.run({
+    cmd: [
+      Deno.execPath(),
+      "eval",
+      "--unstable",
+      "--no-check",
+      code,
+    ],
+    stdout: "piped",
+  });
+  const [status, output] = await Promise.all([p.status(), p.output()]);
+  p.close();
+  return [status.code, decoder.decode(output)];
+}
