@@ -1,5 +1,6 @@
 // Copyright 2018-2022 the Deno authors. All rights reserved. MIT license.
 
+pub mod bench;
 pub mod coverage;
 pub mod doc;
 pub mod fmt;
@@ -7,6 +8,7 @@ pub mod installer;
 pub mod lint;
 pub mod repl;
 pub mod standalone;
+pub mod task;
 pub mod test;
 pub mod upgrade;
 pub mod vendor;
